@@ -27,31 +27,33 @@ setMethod('density', signature(x='RasterStackBrick'),
 		
 		if (missing(layer)) y = 1:nlayers(x)
 		else if (is.character(layer)) {
-			y = .nameToIndex(layer, layerNames(x))
+			y <- match(layer, names(x))
 		} else { 
-			y = layer 
+			y <- layer 
 		}
 		y <- unique(as.integer(round(y)))
-		y = na.omit(y)
-		y = subset(y, y >= 1 & y <= nlayers(x))
+		y <- na.omit(y)
+		y <- subset(y, y >= 1 & y <= nlayers(x))
 		nl <- length(y)
 		if (nl == 0) {stop('no existing layers selected')}
 		
 		if (nl > 1)	{
-			res=list()
+			res <- list()
 			if (nl > 16) {
 				warning('only the first 16 layers are plotted')
 				nl <- 16
 				y <- y[1:16]
 			}
-			if (missing(main)) {	main=layerNames(x) }
+			if (missing(main)) {
+				main=names(x) 
+			}
 
 			nc <- ceiling(sqrt(nl))
 			nr <- ceiling(nl / nc)
 			
 			
-			mfrow = par("mfrow")
-			spots = mfrow[1] * mfrow[2]
+			mfrow <- par("mfrow")
+			spots <- mfrow[1] * mfrow[2]
 			if (spots < nl) {
 				old.par <- par(no.readonly = TRUE) 
 				on.exit(par(old.par))
@@ -60,12 +62,14 @@ setMethod('density', signature(x='RasterStackBrick'),
 			for (i in 1:length(y)) {	
 				r <- raster(x, y[i])
 				m <- main[y[i]]
-				res[[i]] = density(r, maxpixels=maxpixels, main=m, plot=plot, ...)
+				res[[i]] <- density(r, maxpixels=maxpixels, main=m, plot=plot, ...)
 			}		
 		} else if (nl==1) {
-			if (missing(main)) main = layerNames(x)[y]
+			if (missing(main)) {
+				main <- names(x)[y]
+			}
 			r <- raster(x, y)
-			res = density(r, maxpixels=maxpixels, main=main, plot=plot, ...)
+			res <- density(r, maxpixels=maxpixels, main=main, plot=plot, ...)
 		}
 		if (plot) return(invisible(res))
 		else return(res)
