@@ -8,10 +8,12 @@
 
 
 .rasterImagePlot <- function(x, col, add=FALSE, legend=TRUE, horizontal = FALSE, 
-    legend.shrink = 0.5, legend.width = 0.6, legend.mar = ifelse(horizontal, 3.1, 5.1), legend.lab = NULL, graphics.reset = FALSE, 
+    legend.shrink = 0.5, legend.width = 0.6, legend.mar = ifelse(horizontal, 3.1, 5.1),
+	legend.lab = NULL, graphics.reset = FALSE, 
     bigplot = NULL, smallplot = NULL, legend.only = FALSE, 
     lab.breaks = NULL, axis.args = NULL, legend.args = NULL, 
-	interpolate=FALSE, box=TRUE, breaks=NULL, zlim=NULL, fun=NULL, asp, ...) {
+	interpolate=FALSE, box=TRUE, breaks=NULL, zlim=NULL, fun=NULL, asp, 
+	colNA = NA, ...) {
 
 
  	if (missing(asp)) {
@@ -26,6 +28,7 @@
 	asRaster <- function(x, col, breaks=NULL, fun=NULL) {
 		if (!is.null(breaks)) {
 			x[] <- as.numeric(cut(x, breaks, include.lowest=TRUE))
+			
 		} else {
 			if (is.function(fun)) {
 				x[] <- fun(x)
@@ -39,6 +42,9 @@
 			x <- round(x * (length(col)-1) + 1)
 		}
 		x[] <- col[x]
+		if (!is.na(colNA)) {
+			x[is.na(x)] <- rgb(t(col2rgb(colNA)), maxColorValue=255)
+		}
 		as.raster(x)
 	}
 	
