@@ -1,4 +1,4 @@
-# Author: Robert J. Hijmans, r.hijmans@gmail.com
+# Author: Robert J. Hijmans
 # Date : June 2008
 # Version 0.9
 # Licence GPL v3
@@ -24,8 +24,10 @@
 	maxval <- NA
 	nodataval <- -Inf
 	layernames <- ''
+	zvalues <- ''
 	
-	iscat = FALSE
+	isCat <- FALSE
+	ratnames <- rattypes <- ratvalues <- NULL
 	catlevels = matrix(NA)
 
 	for (i in 1:length(ini[,1])) {
@@ -46,8 +48,14 @@
 		else if (ini[i,2] == "MAXVALUE") { try ( maxval <-  as.numeric(unlist(strsplit(ini[i,3], ':'))), silent = TRUE ) }
 		else if (ini[i,2] == "VALUEUNIT") { try ( maxval <-  as.numeric(unlist(strsplit(ini[i,3], ':'))), silent = TRUE ) }
 
-		else if (ini[i,2] == "CATEGORICAL") { try ( iscat <-  as.logical(unlist(strsplit(ini[i,3], ':'))), silent = TRUE ) }
-		else if (ini[i,2] == "LEVELS") { try ( catlevels <-  as.logical(unlist(strsplit(ini[i,3], ':'))), silent = TRUE ) }
+		else if (ini[i,2] == "CATEGORICAL") { try ( isCat <-  as.logical(unlist(strsplit(ini[i,3], ':'))), silent = TRUE ) }
+				
+		#else if (ini[i,2] == "RATROWS") { ratrows <- as.integer(ini[i,3]) }
+		else if (ini[i,2] == "RATNAMES") { ratnames <- unlist(strsplit(ini[i,3], ':')) }
+		else if (ini[i,2] == "RATTYPES") { rattypes <- unlist(strsplit(ini[i,3], ':')) }
+		else if (ini[i,2] == "RATVALUES") { ratvalues <- unlist(strsplit(ini[i,3], ':')) }
+		
+		else if (ini[i,2] == "LEVELS") { try ( catlevels <-  unlist(strsplit(ini[i,3], ':')), silent = TRUE ) }
 		
 		else if (ini[i,2] == "NODATAVALUE") { nodataval <- as.numeric(ini[i,3]) } 
 		else if (ini[i,2] == "DATATYPE") { inidatatype <- ini[i,3] } 
@@ -56,6 +64,7 @@
 		else if (ini[i,2] == "BANDORDER") { bandorder <- ini[i,3] }  
 		else if (ini[i,2] == "PROJECTION") { projstring <- ini[i,3] } 
 		else if (ini[i,2] == "LAYERNAME") { layernames <- ini[i,3] } 
+		else if (ini[i,2] == "ZVALUES") { zvalues <- ini[i,3] } 
     }  
 	
 	if (projstring == 'GEOGRAPHIC') { projstring <- "+proj=longlat" }
@@ -85,10 +94,27 @@
 		x@data@band <- as.integer(band)
 		x@data@min <- minval[band]
 		x@data@max <- maxval[band]
-		x@data@isfactor = iscat
-		if (iscat) { 
-		#	x@data@levels = catlevels 
+	}
+	
+	x@data@isfactor = isCat
+	if (isCat) {
+	
+	# only for a single layer!
+	
+		rat <- data.frame(matrix(ratvalues, nrow=length(ratvalues) / length(ratnames)), stringsAsFactors=FALSE)
+		colnames(rat) <- ratnames
+		for (i in 1:ncol(rat)) {
+			if (rattypes[i] == 'integer') {
+				rat[, i] <- as.integer(rat[,i])
+			} else if (rattypes[i] == 'numeric') {
+				rat[, i] <- as.numeric(rat[,i])
+			} else if (rattypes[i] == 'factor') {
+				rat[, i] <- as.factor(rat[,i])
+			}
 		}
+		x@data@isfactor <- TRUE
+		x@data@attributes <- list(rat)
+		
 	}
 
 	x@file@nbands <- as.integer(nbands)
@@ -108,10 +134,25 @@
 			lnames <- paste(lnames , 1:nbands, sep='_')
 		}
 	}
+
+	if (zvalues != '') {
+		names(zvalues) <- NULL
+		zvalues <- unlist(strsplit(zvalues, ':'))
+		zname <- zvalues[1]
+		zvalues <- zvalues[-1]
+		if (type == 'RasterBrick') {
+			zvalues <- list(zvalues)
+		} else {
+			zvalues <- list(zvalues[band])
+		}
+		names(zvalues) <- zname
+		x@z <- zvalues
+	} 
+	
 	if (type == 'RasterBrick') {
-		layerNames(x) <- lnames
+		names(x) <- lnames
 	} else {
-		layerNames(x) <- lnames[band]
+		names(x) <- lnames[band]
 	}
 	
 	dataType(x) <- inidatatype
