@@ -40,24 +40,37 @@ setMethod ('show' , 'RasterLayer',
 		cat('extent      : ' , object@extent@xmin, ', ', object@extent@xmax, ', ', object@extent@ymin, ', ', object@extent@ymax, '  (xmin, xmax, ymin, ymax)\n', sep="")
 		cat('coord. ref. :' , projection(object, TRUE), '\n')
 		
-		
+
+		if (hasValues(object)) {
+			fd <- object@data@fromdisk
+			if (fd) {
+				cat('values      :', filename(object), '\n')
+			} else {
+				cat('values      : in memory\n')			
+			}
+				
+			cat('layer name  :', names(object), '\n')
+			
+			if (object@data@haveminmax) {
+				cat('min value   :' , minValue(object), '\n')
+				cat('max value   :' , maxValue(object), '\n')
+			}
+		} else {
+			cat('values      : none\n')			
+		}
+
+
 		if (is.factor(object)) {
 		
-			x <- object@data@attributes[[1]][, -c(1:2), drop=FALSE]
+			x <- object@data@attributes[[1]]
 			nc <- ncol(x)
 			maxnl <- 12
 			if (nc > maxnl) {
 				x <- x[, 1:maxnl]
 			}
 			
-			if (ncol(x)== 0) {
-				cat('Raster Attribute Table (empty)\n') 
-				x <- object@data@attributes[[1]]			
-				nc <- 2
-			} else {
-				cat('Raster Attribute Table\n') 
-			}
-			
+			cat('Raster Attribute Table\n') 
+	
 			#nfact <- sapply(1:ncol(x), function(i) is.numeric(x[,i]))
 			r <- apply(x, 2, range, na.rm=TRUE)
 			r <- data.frame(r)
@@ -72,27 +85,6 @@ setMethod ('show' , 'RasterLayer',
 			
 		} else {
 				
-
-			if (hasValues(object)) {
-				fd <- object@data@fromdisk
-				if (fd) {
-					cat('values      :', filename(object), '\n')
-				} else {
-					cat('values      : in memory\n')			
-				}
-				
-				cat('layer name  :', names(object), '\n')
-				
-				if (object@data@haveminmax) {
-					cat('min value   :' , minValue(object), '\n')
-					cat('max value   :' , maxValue(object), '\n')
-				}
-			} else {
-				cat('values      : none\n')			
-			}
-
-
-
 			z <- getZ(object)
 			if (length(z) > 0) {
 				name <- names(object@z)
